pilas.motores.motor_qt

Package pilas :: Package motores :: Module motor_qt |
[hide private]
[frames] | no frames]

# Module motor_qt

source code

Classes | [hide private]
| Ventana
| CanvasWidget
| CanvasWidgetSugar
| BaseActor
| Imagen
| Grilla Representa una grilla regular, que se utiliza en animaciones.
| Texto
| Lienzo
| Superficie
| Actor
| SonidoDeshabilitado
| MusicaDeshabilitada
| SonidoGST
| MusicaGST
| SonidoPhonon
| MusicaPhonon
| Motor Representa la ventana principal de pilas.